<?php

namespace Tests\Feature;

use App\Models\Retailer;
use App\Models\User;
use Hash;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;

class RetailerDeleteTest extends TestCase
{
    public function test_success_delete_retailer_by_admin()
    {
        $user = User::factory()->create([
            'role' => 'admin',
            'password' => Hash::make('123123123'),
        ]);
        $retailer = Retailer::factory()->create();
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->delete('nova-api/retailers?filters=W10%3D&resources[]=' . $retailer->id);
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_success_delete_retailer_by_analyst()
    {
        $user = User::factory()->create([
            'role' => 'analyst',
            'password' => Hash::make('123123123'),
        ]);
        $retailer = Retailer::factory()->create();
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->delete('nova-api/retailers?filters=W10%3D&resources[]=' . $retailer->id);
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_delete_retailer_by_common()
    {
        $user = User::factory()->create([
            'role' => 'common',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $retailer = Retailer::factory()->create();
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]=' . $retailer->id);
        $retailer->delete();
        $user->delete();
        $response->assertStatus(403);
    }

    public function test_delete_retailer_by_unauthenticate_user()
    {
        $retailer = Retailer::factory()->create();
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]=' . $retailer->id);
        $retailer->delete();
        $response->assertStatus(401);
    }
}
